==> vradi-entities-0.0.1-sources.jar: com/jurismarches/vradi/entities/UserBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Date;
import org.sharengo.wikitty.BusinessEntityBean;

public class UserBean extends com.jurismarches.vradi.entities.QueryMakerBean implements User, QueryMaker {

    private static final long serialVersionUID = 79476278L;

    public UserBean() {
        super();
    }

     protected PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String User$name;

     public String User$service;

     public String User$email;

     public Date User$creationDate;

     public boolean User$validEmail;

     public String User$address;

     public String User$phone;

 
    public void setName(String value) {
        Object oldValue = User$name; 
        this.User$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return User$name;
    }


    public void setService(String value) {
        Object oldValue = User$service; 
        this.User$service = value;
        propertyChange.firePropertyChange("service", oldValue, value);
    }

    public String getService() {
        return User$service;
    }


    public void setEmail(String value) {
        Object oldValue = User$email; 
        this.User$email = value;
        propertyChange.firePropertyChange("email", oldValue, value);
    }

    public String getEmail() {
        return User$email;
    }


    public void setCreationDate(Date value) {
        Object oldValue = User$creationDate; 
        this.User$creationDate = value;
        propertyChange.firePropertyChange("creationDate", oldValue, value);
    }

    public Date getCreationDate() {
        return User$creationDate;
    }


    public void setValidEmail(boolean value) {
        Object oldValue = User$validEmail; 
        this.User$validEmail = value;
        propertyChange.firePropertyChange("validEmail", oldValue, value);
    }

    public boolean getValidEmail() {
        return User$validEmail;
    }


    public void setAddress(String value) {
        Object oldValue = User$address; 
        this.User$address = value;
        propertyChange.firePropertyChange("address", oldValue, value);
    }

    public String getAddress() {
        return User$address;
    }


    public void setPhone(String value) {
        Object oldValue = User$phone; 
        this.User$phone = value;
        propertyChange.firePropertyChange("phone", oldValue, value);
    }

    public String getPhone() {
        return User$phone;
    }

    public java.util.Set<String> QueryMaker$queries;

     public java.util.Set<String> getQueries() {
        return QueryMaker$queries;
    }

    public void addQueries(String element) {
        QueryMaker$queries.add(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void removeQueries(String element) {
        QueryMaker$queries.remove(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void clearQueries() {
        QueryMaker$queries.clear();
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }


} //UserBean

==> vradi-entities-0.0.4-sources.jar: com/jurismarches/vradi/entities/UserBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntityBean;

public class UserBean extends com.jurismarches.vradi.entities.QueryMakerBean implements User, QueryMaker {

    private static final long serialVersionUID = 79476278L;

    public UserBean() {
        super();
    }

     protected PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String User$name;

     public String User$service;

     public String User$email;

     public Date User$creationDate;

     public boolean User$validEmail;

     public String User$address;

     public String User$phone;

     public String User$client;

     public Set<String> User$group;

 
    public void setName(String value) {
        Object oldValue = User$name; 
        this.User$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return User$name;
    }


    public void setService(String value) {
        Object oldValue = User$service; 
        this.User$service = value;
        propertyChange.firePropertyChange("service", oldValue, value);
    }

    public String getService() {
        return User$service;
    }


    public void setEmail(String value) {
        Object oldValue = User$email; 
        this.User$email = value;
        propertyChange.firePropertyChange("email", oldValue, value);
    }

    public String getEmail() {
        return User$email;
    }


    public void setCreationDate(Date value) {
        Object oldValue = User$creationDate; 
        this.User$creationDate = value;
        propertyChange.firePropertyChange("creationDate", oldValue, value);
    }

    public Date getCreationDate() {
        return User$creationDate;
    }


    public void setValidEmail(boolean value) {
        Object oldValue = User$validEmail; 
        this.User$validEmail = value;
        propertyChange.firePropertyChange("validEmail", oldValue, value);
    }

    public boolean getValidEmail() {
        return User$validEmail;
    }


    public void setAddress(String value) {
        Object oldValue = User$address; 
        this.User$address = value;
        propertyChange.firePropertyChange("address", oldValue, value);
    }

    public String getAddress() {
        return User$address;
    }


    public void setPhone(String value) {
        Object oldValue = User$phone; 
        this.User$phone = value;
        propertyChange.firePropertyChange("phone", oldValue, value);
    }

    public String getPhone() {
        return User$phone;
    }


    public void setClient(String value) {
        Object oldValue = User$client; 
        this.User$client = value;
        propertyChange.firePropertyChange("client", oldValue, value);
    }

    public String getClient() {
        return User$client;
    }

    public Set<String> getGroup() {
        return User$group;
    }

    public void addGroup(String element) {
        User$group.add(element);
        propertyChange.firePropertyChange("group", null, User$group);
    }
    
    public void removeGroup(String element) {
        User$group.remove(element);
        propertyChange.firePropertyChange("group", null, User$group);
    }
    
    public void clearGroup() {
        User$group.clear();
        propertyChange.firePropertyChange("group", null, User$group);
    }

    public Set<String> QueryMaker$queries;

     public Set<String> getQueries() {
        return QueryMaker$queries;
    }

    public void addQueries(String element) {
        QueryMaker$queries.add(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void removeQueries(String element) {
        QueryMaker$queries.remove(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void clearQueries() {
        QueryMaker$queries.clear();
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }


} //UserBean
